import inspect

class TestSuite:
    def __init__(self, test_cases):
        self.test_cases = test_cases

    def get_tests(self):
        tests = []
        for test_case in self.test_cases:
            
            methods = inspect.getmembers(test_case, predicate=inspect.ismethod)
            
            filtered_methods = [method for name, method in methods if hasattr(method, '_is_test')]
            tests.extend(filtered_methods)
        return tests



from reporter import TestReporter
from logger import TestLogger

class TestRunner:
    def __init__(self, suite, logger=None):
        self.suite = suite
        self.logger = logger or TestLogger()
        self.reporter = TestReporter()

    def run_tests(self):
        results = []
        for test in self.suite.get_tests():
            try:
                self.logger.log(f"Running test: {test.__name__}")
                test()
                results.append((test.__name__, 'pass'))
            except Exception as e:
                results.append((test.__name__, f'fail: {str(e)}'))
        return results



import logging

class TestLogger:
    def __init__(self, level=logging.INFO):
        logging.basicConfig(level=level)
        self.logger = logging.getLogger('TestLogger')

    def log(self, message):
        self.logger.info(message)

    def set_level(self, level):
        self.logger.setLevel(level)
